@@ -1,4 +1,4 @@
-#  Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
+#  Copyright (c) 2025 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
 #  All rights reserved.
 #
 #  This file is part of the simtrial program.
@@ -126,6 +126,7 @@ rmst <- function(
 #' - `rmst_diff`: the calculation results of RMST differences.
 #'
 #' @importFrom data.table setDF rbindlist
+#' @importFrom survival Surv
 #' @keywords internal
 #'
 #' @examples
@@ -280,7 +281,7 @@ rmst_single_arm <- function(
   stopifnot(0 <= alpha & alpha <= 1)
 
   # Fit a single Kaplan-Meier curve
-  fit <- survival::survfit(survival::Surv(time_var, event_var) ~ 1)
+  fit <- survival::survfit(Surv(time_var, event_var) ~ 1)
 
   # Extract survival probability, number of event, number at risk,
   # and number of censored along with observed time from the fitted model
