@@ -12,7 +12,7 @@ test_that("the p-values correspond to pvalue_maxcombo", {
   HT.est <- FALSE
   max <- TRUE
   alpha <- 0.025
-  fit <- survMisc::ten(survival::Surv(y$tte, y$event) ~ y$treatment, data = y)
+  fit <- survMisc::ten(Surv(y$tte, y$event) ~ y$treatment, data = y)
 
   # Testing
   survMisc::comp(fit, p = sapply(wt, function(x) x[1]), q = sapply(wt, function(x) x[2])) |>
@@ -35,7 +35,7 @@ test_that("the p-values correspond to pvalue_maxcombo", {
   d1 <- data.frame(do.call(rbind, wt2))
   wt3 <- unique(wt2)
   d2 <- data.frame(do.call(rbind, wt3))
-  fit2 <- survMisc::ten(survival::Surv(y$tte, y$event) ~ y$treatment, data = y)
+  fit2 <- survMisc::ten(Surv(y$tte, y$event) ~ y$treatment, data = y)
 
   # Testing (for calculating the covariances)
   survMisc::comp(fit2, p = sapply(wt3, function(x) x[1]), q = sapply(wt3, function(x) x[2])) |>
